; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


;-| Super Motions |--------------------------------------------------------
;[Command]
;name = "TestEnd"
;command = ~F, B, F, x
;time = 30

[Command]
name = "SuperLeigun"
command = ~D, F, D, F, x
time = 30

[Command]
name = "SuperLeigun"
command = ~D, F, D, F, y
time = 30

[Command]
name = "SuperLeigun"
command = ~D, F, D, F, z
time = 30

[Command]
name = "Leikoudan"
command = ~D, F, D, F, a
time = 25

[Command]
name = "Leikoudan"
command = ~D, F, D, F, b
time = 25

[Command]
name = "Leikoudan"
command = ~D, F, D, F, c
time = 25

[Command]
name = "SpecialSkill"
command = ~D, DB, B, a
time = 15

[Command]
name = "SpecialSkill"
command = ~D, DB, B, b
time = 15

[Command]
name = "SpecialSkill"
command = ~D, DB, B, c
time = 15

;-| Special Motions |------------------------------------------------------
[Command]
name = "Shotgun"
command = ~60$B, F, x

[Command]
name = "Shotgun"
command = ~60$B, F, y

[Command]
name = "Shotgun"
command = ~60$B, F, z

[Command]
name = "QCB"
command = ~D, DB, B, x

[Command]
name = "QCB"
command = ~D, DB, B, y

[Command]
name = "QCB"
command = ~D, DB, B, z

[Command]
name = "Leigun"
command = ~D, DF, F, x

[Command]
name = "Leigun"
command = ~D, DF, F, y

[Command]
name = "Leigun"
command = ~D, DF, F, z

[Command]
name = "Leigun"
command = ~D, DF, F, s

[Command]
name = "Uppercut"
command = ~F, D, DF, x

[Command]
name = "Uppercut"
command = ~F, D, DF, y

[Command]
name = "Uppercut"
command = ~F, D, DF, z

;[Command]
;name = "SlashDownKick"
;command = ~F, DF, D, a

;[Command]
;name = "SlashDownKick"
;command = ~F, DF, D, b

;[Command]
;name = "SlashDownKick"
;command = ~F, DF, D, c

[Command]
name = "FakeLeigun"
command = ~D, DF, F, s

[Command]
name = "FakeUppercut"
command = ~F, D, DF, s

[Command]
name = "FakeShotgun"
command = ~D, DB, B, s

[Command]
name = "StrikerA"
command = ~D, DF, F, a

[Command]
name = "StrikerB"
command = ~D, DF, F, b

[Command]
name = "StrikerC"
command = ~D, DF, F, c

[Command]
name = "CounterAttack"
command = ~DB, D, x

[Command]
name = "CounterAttack"
command = ~DB, D, y

[Command]
name = "CounterAttack"
command = ~DB, D, z

[Command]
name = "Counter2"
command = ~DB, D, a

[Command]
name = "Counter2"
command = ~DB, D, b

[Command]
name = "Counter2"
command = ~DB, D, c

[Command]
name = "Dodge"
command = x+y

[Command]
name = "Dodge"
command = x+z

[Command]
name = "Dodge"
command = y+z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "recovery";Required (do not remove)
command = c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "roll_f"
command = /$F, z

[Command]
name = "roll_b"
command = /$B, z

;[Command]
;name = "elbow"
;command = /F, x

;[Command]
;name = "knee"
;command = /F, a

[Command]
name = "overhead"
command = /F, c

;[Command]
;name = "fc"
;command = /F, c

[Command]
name = "Headbutt"
command = /F, y

;[Command]
;name = "Throw"
;command = /F, z

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "charge"
command = /s
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holds"
command = /s
time = 1

;[Command]
;name = "taunt"
;command = s
;time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.

; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;[State -1]
;trigger1 = command = "TestEnd"
;type = changestate
;value = 6900

[State -1, Leikoudan]
type = ChangeState
value = 3100
triggerall = command = "Leikoudan"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)

[State -1, Super Leigun]
type = ChangeState
value = 3000
triggerall = command = "SuperLeigun"
triggerall = power >= 1000
triggerall = numprojid(1010) = 0
triggerall = numprojid(3000) = 0
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Pursuit]
type = ChangeState
value = 730
triggerall = p2statetype = L
triggerall = command = "holdup"
triggerall = pos y > -9
triggerall = (stateno = [0,40]) || ((stateno = 41) && (time < 1))
triggerall = p2stateno != 5120
trigger1 = command = "x"
trigger2 = command = "y"
trigger3 = command = "z"

[State -1]
type = ChangeState
triggerall = command = "CounterAttack"
triggerall = (power >= 750) || ((var(5) > 0) && (power >= 333))
triggerall = pos y > -7
triggerall = alive
trigger1 = stateno = [150,155]
value = 1050

[State -1]
type = ChangeState
triggerall = command = "Counter2"
triggerall = var(16) > 0
triggerall = pos y > -7
triggerall = alive
trigger1 = stateno = [150,155]
value = 6100

;[State -1, Slash Down Kick]
;type = ChangeState
;value = 1060
;triggerall = command = "SlashDownKick"
;triggerall = prevstateno != 1061
;trigger1 = statetype = A
;trigger1 = ctrl

;[State -1, Slash Kick]
;type = ChangeState
;value = 1070
;triggerall = command = "Slash Kick"
;trigger1 = statetype != A
;trigger1 = ctrl

;[State -1, Slide Kick]
;type = ChangeState
;value = 1080
;triggerall = command = "SlashDownKick"
;trigger1 = statetype != A
;trigger1 = ctrl

[State -1, Special Skills]
type = ChangeState
value = 3200
triggerall = command = "SpecialSkill"
triggerall = power >= 1000
triggerall = (var(3) = 0) && (var(4) = 0) && (var(5) = 0)
;trigger1 = statetype != A
trigger1 = ctrl

[State -1, Kuwabara - A]
triggerall = command = "StrikerA"
triggerall = numhelper(6000) = 0
triggerall = var(16) > 0
trigger1 = ctrl
trigger2 = stateno = [200,650]
type = changestate
value = 6010

[State -1, Kuwabara - B]
triggerall = command = "StrikerB"
triggerall = numhelper(6000) = 0
triggerall = var(16) > 0
trigger1 = ctrl
;trigger1 = statetype != A
trigger2 = stateno = [200,650]
type = changestate
value = 6011

[State -1, Kuwabara - C]
triggerall = command = "StrikerC"
triggerall = numhelper(6000) = 0
triggerall = var(16) > 0
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = stateno = [200,650]
type = changestate
value = 6012

[State -1, Shotgun]
type = ChangeState
value = 1010
triggerall = command = "Shotgun"
triggerall = power > 333
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 1010

[State -1, Uppercut]
type = ChangeState
value = 1050
triggerall = command = "Uppercut"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 1050
trigger3 = stateno = 210
trigger3 = command = "holdz"
trigger3 = movecontact
trigger4 = stateno = 240
trigger4 = command = "holdz"
trigger4 = movecontact

[State -1, Leigun]
type = ChangeState
value = 1000 + (var(4) > 0)
triggerall = command = "Leigun"
triggerall = NumProjId(1000) = 0
triggerall = stateno != [1000,1001]
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,250]) || (stateno = [400,440])
trigger2 = movecontact
trigger3 = var(3) && stateno != [3100,3110]
trigger3 = (movecontact) && (statetype = S)
trigger3 = stateno != 1000

[State -1, Cabeada]
type = ChangeState
value = 1090
triggerall = command = "Headbutt"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = stateno != [1000,1001]
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

[State -1, Run Back]
type = ChangeState
value = 105
triggerall = stateno != [1000,1001]
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

[State -1, Overhead]
type = ChangeState
value = 270
triggerall = command = "overhead"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 270

;[State -1, Foward + c]
;type = ChangeState
;value = 260
;triggerall = command = "fc"
;triggerall = command != "holddown"
;trigger1 = statetype = S
;trigger1 = ctrl
;trigger2 = stateno = 220
;trigger2 = movecontact
;trigger3 = stateno = 240
;trigger3 = movecontact

[State -1,Esquiva]
type = changestate
value = 700
triggerall = command = "Dodge"
trigger1 = statetype = S
trigger1 = ctrl

[State -1,PowerCounter]
type = changestate
value = 220
triggerall = var(5)
triggerall = stateno = 130 || stateno = 150
trigger1 = command = "x"
trigger2 = command = "y"
trigger3 = command = "z"

[State -1,PowerCounter]
type = changestate
value = 220
triggerall = var(5)
triggerall = ((stateno = [151,154]) || (stateno = 131)) && (pos y > -7)
trigger1 = command = "x"
trigger2 = command = "y"
trigger3 = command = "z"

[State -1,PowerCounter]
type = changestate
value = 450
triggerall = var(5)
triggerall = stateno = 130 || stateno = 150
trigger1 = command = "a"
trigger2 = command = "b"
trigger3 = command = "c"

[State -1,PowerCounter]
type = changestate
value = 450
triggerall = var(5)
triggerall = ((stateno = [151,154]) || (stateno = 131)) && (pos y > -7)
trigger1 = command = "a"
trigger2 = command = "b"
trigger3 = command = "c"

[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 200
;trigger3 = stateno = [1000,1001]
;trigger3 = var(9) = 4

[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 230
trigger3 = movecontact
trigger4 = var(3) && stateno != [3100,3110]
trigger4 = (movecontact) && (statetype = S)
trigger4 = stateno != 210
;trigger5 = stateno = [1000,1001]
;trigger5 = var(9) = 4

[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 210
trigger2 = movecontact
trigger3 = stateno = 240
trigger3 = movecontact
trigger4 = var(3) && stateno != [3100,3110]
trigger4 = (movecontact) && (statetype = S)
trigger4 = stateno != 220
;trigger5 = stateno = [1000,1001]
;trigger5 = var(9) = 4

[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = var(3) && stateno != [3100,3110]
trigger3 = (movecontact) && (statetype = S)
trigger3 = stateno != 230
;trigger4 = stateno = [1000,1001]
;trigger4 = var(9) = 4

[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 210
trigger2 = movecontact
trigger3 = stateno = 230
trigger3 = movecontact
trigger4 = var(3) && stateno != [3100,3110]
trigger4 = (movecontact) && (statetype = S)
trigger4 = stateno != 240
;trigger5 = stateno = [1000,1001]
;trigger5 = var(9) = 4

[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 220
trigger2 = movecontact
trigger3 = stateno = 240
trigger3 = movecontact
trigger4 = var(3) && stateno != [3100,3110]
trigger4 = (movecontact) && (statetype = S)
trigger4 = stateno != 250
;trigger5 = stateno = [1000,1001]
;trigger5 = var(9) = 4

[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 400
trigger3 = stateno = [1000,1001]
trigger3 = var(9) = 4

[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 410
trigger3 = movecontact
trigger3 = stateno = 400 || stateno = 430
trigger4 = stateno = [200,210]
trigger4 = movecontact
trigger5 = stateno = [1000,1001]
trigger5 = var(9) = 4

[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 420
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact
trigger5 = stateno = [1000,1001]
trigger5 = var(9) = 4

[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 430
trigger3 = stateno = 400
trigger3 = movecontact
trigger4 = stateno = [1000,1001]
trigger4 = var(9) = 4

[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 440
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = stateno = 430
trigger4 = movecontact
trigger5 = stateno = [1000,1001]
trigger5 = var(9) = 4

[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = var(3) && stateno != [3100,3110]
trigger2 = (movecontact) && (statetype = S)
trigger2 = stateno != 450
trigger3 = stateno = 420 || stateno = 440 || stateno = 250
trigger3 = movecontact
trigger4 = stateno = [1000,1001]
trigger4 = var(9) = 4

[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = [100,105]
trigger3 = var(5)
trigger3 = ((stateno = [151,154]) || (prevstateno = 132)) && (pos y < -7)

[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) || (stateno = 630)
trigger2 = movecontact
trigger3 = stateno = [100,105]
trigger4 = var(5)
trigger4 = ((stateno = [151,154]) || (prevstateno = 132)) && (pos y < -7)

[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = movecontact
trigger3 = stateno = 640
trigger3 = movecontact
trigger4 = stateno = [100,105]
trigger5 = var(5)
trigger5 = ((stateno = [151,154]) || (prevstateno = 132)) && (pos y < -7)

[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = movecontact
trigger3 = stateno = [100,105]
trigger4 = var(5)
trigger4 = ((stateno = [151,154]) || (prevstateno = 132)) && (pos y < -7)

[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = movecontact
trigger3 = stateno = 630
trigger3 = movecontact
trigger4 = stateno = [100,105]
trigger5 = var(5)
trigger5 = ((stateno = [151,154]) || (prevstateno = 132)) && (pos y < -7)

[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 640
trigger2 = movecontact
trigger3 = stateno = 620
trigger3 = movecontact
trigger4 = stateno = [100,105]
trigger5 = var(5)
trigger5 = ((stateno = [151,154]) || (prevstateno = 132)) && (pos y < -7)

;Ki Charge
[State -1, Charge]
type = ChangeState
triggerall = command = "charge"
triggerall = power <= 3000
triggerall = command != "Leigun"
triggerall = stateno != [1000,1001]
trigger1 = ctrl
trigger1 = statetype != A
value = 900

;[State -1, Taunt]
;type = ChangeState
;value = 195
;triggerall = command = "taunt"
;trigger1 = statetype = S
;trigger1 = ctrl

[State -1, Rolagem]
type = ChangeState
value = 710
triggerall = statetype = L
trigger1 = command = "Leigun"
trigger2 = command = "StrikerA"
trigger3 = command = "StrikerB"
trigger4 = command = "StrikerC"

[State -1, Rolagem]
type = ChangeState
value = 720
triggerall = statetype = L
trigger1 = command = "QCB"
trigger2 = command = "SpecialSkill"
